@@ -30,6 +30,6 @@ class Settings(BaseSettings):
         env_file = ".env"
 
 
-@lru_cache
+@lru_cache()
 def get_settings():
     return Settings()  # type: ignore
